@@ -1,6 +1,9 @@
-package # hide from PAUSE 
+package # hide from PAUSE
     DBICTest::Taint::Namespaces::Result::Test;
 
+use warnings;
+use strict;
+
 use base 'DBIx::Class::Core';
 __PACKAGE__->table('test');
 
